==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fr/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Cet utilisateur peut se connecter',
    'activated_disabled_help_text' => 'Vous ne pouvez pas modifier l\'état de votre propre compte.',
    'assets_user'       => 'Actifs associés avec :name',
    'bulk_update_warn'	=> 'Vous êtes sur le point de modifier les propriétés de: user_count users. Veuillez noter que vous ne pouvez pas modifier vos propres attributs d\'utilisateur en utilisant ce formulaire et devez effectuer des modifications à votre propre utilisateur individuellement.',
    'bulk_update_help'	=> 'Ce formulaire vous permet de mettre à jour plusieurs utilisateurs à la fois. Remplissez uniquement les champs que vous devez modifier. Tous les champs laissés vides resteront inchangés.',
    'current_assets'    => 'Biens actuellement attribués à cet utilisateur',
    'clone'             => 'Cloner l\'utilisateur',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Modifier l\'utilisateur',
    'filetype_info'     => 'Types de fichier autorisés: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Historique pour :name',
	'info'				=> 'Info',
    'restore_user'		=> 'Cliquez ici pour les restaurer.',
    'last_login'        => 'Dernière connexion',
    'ldap_config_text'  => 'Les paramètres de configuration LDAP se trouvent sous Admin > Réglages. La localisation sélectionnée (optionnelle) sera définie pour tous les utilisateurs importés.',
    'print_assigned'    => 'Imprimer tout ceux assignés',
    'software_user'     => 'Logiciels associés avec :name',
    'send_email_help'   => 'Vous devez fournir une adresse e-mail pour que cet utilisateur puisse recevoir ses identifiants. Les envois d\'identifiants par email ne peuvent être faits que lors de la création de l\'utilisateur. Les mots de passe sont stockés dans un hachage à sens unique et ne peuvent pas être récupérés une fois enregistrés.',
    'view_user'         => 'Voir l\'utilisateur :name',
    'usercsv'           => 'Fichier CSV',
    'two_factor_admin_optin_help' => 'Vos paramètres administratifs actuels permettent une application sélective de l\'authentification à deux facteurs.  ',
    'two_factor_enrolled' => 'Dispositif à deux facteurs inscrit ',
    'two_factor_active'   => 'Activation des deux facteurs ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fr/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Cet utilisateur peut se connecter',
    'activated_disabled_help_text' => 'Vous ne pouvez pas modifier l\'état de votre propre compte.',
    'assets_user'       => 'Actifs associés avec :name',
    'bulk_update_warn'	=> 'Vous êtes sur le point de modifier les propriétés de: user_count users. Veuillez noter que vous ne pouvez pas modifier vos propres attributs d\'utilisateur en utilisant ce formulaire et devez effectuer des modifications à votre propre utilisateur individuellement.',
    'bulk_update_help'	=> 'Ce formulaire vous permet de mettre à jour plusieurs utilisateurs à la fois. Remplissez uniquement les champs que vous devez modifier. Tous les champs laissés vides resteront inchangés.',
    'current_assets'    => 'Biens actuellement attribués à cet utilisateur',
    'clone'             => 'Cloner l\'utilisateur',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Modifier l\'utilisateur',
    'filetype_info'     => 'Types de fichier autorisés: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Historique pour :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Cliquez ici pour les restaurer.',
    'last_login'        => 'Dernière connexion',
    'ldap_config_text'  => 'Les paramètres de configuration LDAP se trouvent sous Admin > Réglages. La localisation sélectionnée (optionnelle) sera définie pour tous les utilisateurs importés.',
    'print_assigned'    => 'Imprimer tout ceux assignés',
    'software_user'     => 'Logiciels associés avec :name',
    'send_email_help'   => 'Vous devez fournir une adresse e-mail pour que cet utilisateur puisse recevoir ses identifiants. Les envois d\'identifiants par email ne peuvent être faits que lors de la création de l\'utilisateur. Les mots de passe sont stockés dans un hachage à sens unique et ne peuvent pas être récupérés une fois enregistrés.',
    'view_user'         => 'Voir l\'utilisateur :name',
    'usercsv'           => 'Fichier CSV',
    'two_factor_admin_optin_help' => 'Vos paramètres administratifs actuels permettent une application sélective de l\'authentification à deux facteurs.  ',
    'two_factor_enrolled' => 'Dispositif à deux facteurs inscrit ',
    'two_factor_active'   => 'Activation des deux facteurs ',
    'user_deactivated'  => 'L\'utilisateur est désactivé',
    'activation_status_warning' => 'Ne pas modifier le statut d\'activation',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Supprimer les appartenances de groupe',
    'warning_deletion' => 'AVERTISSEMENT :',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
